"use strict";

exports.__esModule = true;
exports.getInitialURL = exports.canOpenURL = exports.openURL = exports.removeEventListener = exports.addEventListener = void 0;

var _electron = require("electron");

const eventHandlers = new Map();

const addEventListener = (type, handler) => {
  if (type === 'url' && typeof handler === 'function') {
    const wrapHandler = (event, url) => {
      handler({
        type,
        url
      });
    };

    eventHandlers.set(handler, wrapHandler);

    _electron.remote.app.on('open-url', wrapHandler);
  }
};

exports.addEventListener = addEventListener;

const removeEventListener = (type, handler) => {
  if (type === 'url' && typeof handler === 'function') {
    const wrapHandler = eventHandlers.get(handler);

    if (wrapHandler) {
      _electron.remote.app.removeListener('open-url', wrapHandler);
    }

    eventHandlers.delete(handler);
  }
};

exports.removeEventListener = removeEventListener;

const openURL = (url, options) => {
  return _electron.shell.openExternal(url, options) ? Promise.resolve() : Promise.reject(new Error('Could not open URL'));
}; // Apply same behavior as RNW


exports.openURL = openURL;

const canOpenURL = () => Promise.resolve(true);

exports.canOpenURL = canOpenURL;

const getInitialURL = () => {
  return Promise.resolve(_electron.remote.process.argv[1] || null);
};

exports.getInitialURL = getInitialURL;